@@ -1,5 +1,5 @@
-__version__ = "1.1.1"
-from ._coordinates import SphericalCoordinates
+__version__ = "1.1.6"
+from ._coordinates import BranchingType, SphericalCoordinates, get_child, get_parent
 from ._creation import (
     c_spherical,
     from_branching_types,
@@ -14,7 +14,6 @@ from ._integral import integrate, roots
 from ._random import random_ball
 from .special import (
     fundamental_solution,
-    lgamma,
     potential_coef,
     shn1,
     shn2,
@@ -24,14 +23,16 @@ from .special import (
 )
 
 __all__ = [
+    "BranchingType",
     "SphericalCoordinates",
     "c_spherical",
     "draw",
     "from_branching_types",
     "fundamental_solution",
+    "get_child",
+    "get_parent",
     "hopf",
     "integrate",
-    "lgamma",
     "polar",
     "potential_coef",
     "random",
